========
Examples
========

Using the Domain module
-----------------------

In this example, we want to show how to use the :module:`domain` to 
create grid data of the CORDEX-CORE domains.

.. literalinclude:: ../examples/domain/domain.py
   :language: python


ESGF Access
-----------

This example shows how to use the :module:`esgf_access` to create
a datatable of EURO-CORDEX simulations available in the ESGF.

.. literalinclude:: ../examples/esgf/access-esgf.py
   :language: python
